| 192.168.56.10   | kingslanding.sevenkingdoms.local   | windows                                 |
|:----------------|:-----------------------------------|:----------------------------------------|
| 53/tcp          | domain                             | Simple DNS Plus                         |
| 80/tcp          | http                               | Microsoft IIS httpd/10.0                |
| 88/tcp          | kerberos-sec                       | Microsoft Windows Kerberos              |
| 135/tcp         | msrpc                              | Microsoft Windows RPC                   |
| 139/tcp         | netbios-ssn                        | Microsoft Windows netbios-ssn           |
| 389/tcp         | ldap                               | Microsoft Windows Active Directory LDAP |
| 445/tcp         | microsoft-ds                       |                                         |
| 464/tcp         | kpasswd5                           |                                         |
| 593/tcp         | ncacn\_http                        | Microsoft Windows RPC over HTTP/1.0     |
| 636/tcp         | ldap                               | Microsoft Windows Active Directory LDAP |
| 3268/tcp        | ldap                               | Microsoft Windows Active Directory LDAP |
| 3269/tcp        | ldap                               | Microsoft Windows Active Directory LDAP |
| 3389/tcp        | ms-wbt-server                      | Microsoft Terminal Services             |
| 5985/tcp        | http                               | Microsoft HTTPAPI httpd/2.0             |
| 5986/tcp        | http                               | Microsoft HTTPAPI httpd/2.0             |


| 192.168.56.11   | winterfell.north.sevenkingdoms.local   | windows                                 |
|:----------------|:---------------------------------------|:----------------------------------------|
| 53/tcp          | domain                                 | Simple DNS Plus                         |
| 88/tcp          | kerberos-sec                           | Microsoft Windows Kerberos              |
| 135/tcp         | msrpc                                  | Microsoft Windows RPC                   |
| 139/tcp         | netbios-ssn                            | Microsoft Windows netbios-ssn           |
| 389/tcp         | ldap                                   | Microsoft Windows Active Directory LDAP |
| 445/tcp         | microsoft-ds                           |                                         |
| 464/tcp         | kpasswd5                               |                                         |
| 593/tcp         | ncacn\_http                            | Microsoft Windows RPC over HTTP/1.0     |
| 636/tcp         | ldap                                   | Microsoft Windows Active Directory LDAP |
| 3268/tcp        | ldap                                   | Microsoft Windows Active Directory LDAP |
| 3269/tcp        | ldap                                   | Microsoft Windows Active Directory LDAP |
| 3389/tcp        | ms-wbt-server                          | Microsoft Terminal Services             |
| 5985/tcp        | http                                   | Microsoft HTTPAPI httpd/2.0             |
| 5986/tcp        | http                                   | Microsoft HTTPAPI httpd/2.0             |


| 192.168.56.22   | castelblack.north.sevenkingdoms.local   | windows                                      |
|:----------------|:----------------------------------------|:---------------------------------------------|
| 80/tcp          | http                                    | Microsoft IIS httpd/10.0                     |
| 135/tcp         | msrpc                                   | Microsoft Windows RPC                        |
| 139/tcp         | netbios-ssn                             | Microsoft Windows netbios-ssn                |
| 445/tcp         | microsoft-ds                            |                                              |
| 1433/tcp        | ms-sql-s                                | Microsoft SQL Server 2019/15.00.2000.00; RTM |
| 3389/tcp        | ms-wbt-server                           | Microsoft Terminal Services                  |
| 5985/tcp        | http                                    | Microsoft HTTPAPI httpd/2.0                  |
| 5986/tcp        | http                                    | Microsoft HTTPAPI httpd/2.0                  |